==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QRegularExpressionValidator_shell.h <==
#ifndef QREGULAREXPRESSIONVALIDATOR_SHELL_H
#define QREGULAREXPRESSIONVALIDATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qvalidator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QRegularExpressionValidator_shell : public QRegularExpressionValidator, public QtJambiShellInterface
{
public:
    QRegularExpressionValidator_shell(QObject* parent0 = nullptr);
    QRegularExpressionValidator_shell(const QRegularExpression& re0, QObject* parent1 = nullptr);
    ~QRegularExpressionValidator_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fixup(QString& arg__1) const override;
    void timerEvent(QTimerEvent* event0) override;
    QValidator::State validate(QString& input0, int& pos1) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRegularExpressionValidator_access : public QRegularExpressionValidator
{
    jint __qt_validate_ref_QString_ref_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject input0) const;
};

#endif // QREGULAREXPRESSIONVALIDATOR_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QRegularExpressionValidator_shell.h <==
#ifndef QREGULAREXPRESSIONVALIDATOR_SHELL_H
#define QREGULAREXPRESSIONVALIDATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qvalidator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QRegularExpressionValidator_shell : public QRegularExpressionValidator, public QtJambiShellInterface
{
public:
    QRegularExpressionValidator_shell(QObject* parent0 = nullptr);
    QRegularExpressionValidator_shell(const QRegularExpression& re0, QObject* parent1 = nullptr);
    ~QRegularExpressionValidator_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QRegularExpressionValidator_mshell;
    friend class QRegularExpressionValidator_oshell;
};


class QRegularExpressionValidator_mshell : public QRegularExpressionValidator_shell
{
public:
    using QRegularExpressionValidator_shell::QRegularExpressionValidator_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QRegularExpressionValidator_oshell : public QRegularExpressionValidator_mshell
{
public:
    using QRegularExpressionValidator_mshell::QRegularExpressionValidator_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fixup(QString& arg__1) const override;
    void timerEvent(QTimerEvent* event0) override;
    QValidator::State validate(QString& input0, int& pos1) const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRegularExpressionValidator_access : public QRegularExpressionValidator
{
    jint __qt_validate_ref_QString_ref_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject input0) const;
};

#endif // QREGULAREXPRESSIONVALIDATOR_SHELL_H
